fitSccsModel: Fit the SCCS model

View source: R/ModelFitting.R

fitSccsModelR Documentation

Fit the SCCS model

Description

Fit the SCCS model

Usage

fitSccsModel(sccsIntervalData, fitSccsModelArgs)

Arguments

sccsIntervalData

An object of type SccsIntervalData as created using the createSccsIntervalData function.

fitSccsModelArgs

An object of type FitSccsModelArgs as created by the createFitSccsModelArgs() function.

Details

Fits the SCCS model as a conditional Poisson regression. When allowed, coefficients for some or all covariates can be regularized.

Value

An object of type SccsModel. Generic functions print, coef, and confint are available.

References

Suchard, M.A., Simpson, S.E., Zorych, I., Ryan, P., and Madigan, D. (2013). Massive parallelization of serial inference algorithms for complex generalized linear models. ACM Transactions on Modeling and Computer Simulation 23, 10


SelfControlledCaseSeries documentation built on May 8, 2026, 5:08 p.m.