| fitSccsModel | R Documentation |
Fit the SCCS model
fitSccsModel(sccsIntervalData, fitSccsModelArgs)
sccsIntervalData |
An object of type SccsIntervalData as created using the createSccsIntervalData function. |
fitSccsModelArgs |
An object of type |
Fits the SCCS model as a conditional Poisson regression. When allowed, coefficients for some or all covariates can be regularized.
An object of type SccsModel. Generic functions print, coef, and
confint are available.
Suchard, M.A., Simpson, S.E., Zorych, I., Ryan, P., and Madigan, D. (2013). Massive parallelization of serial inference algorithms for complex generalized linear models. ACM Transactions on Modeling and Computer Simulation 23, 10
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.